# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import token_pb2 as token__pb2


class TokenApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.TokenApi/create',
                request_serializer=token__pb2.TokenCreateRequest.SerializeToString,
                response_deserializer=token__pb2.TokenCreateResponse.FromString,
                )


class TokenApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        As an authenticated user, generate a new API token, often one that lives longer to continue to use the system.
        By default, new tokens last for an hour. The maximum duration of a token is currently 1 year.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=token__pb2.TokenCreateRequest.FromString,
                    response_serializer=token__pb2.TokenCreateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.TokenApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TokenApi/create',
            token__pb2.TokenCreateRequest.SerializeToString,
            token__pb2.TokenCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
