# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\xc3\x01\n\x19SubscriptionCreateRequest\x12\x46\n\rsubscriptions\x18\x01 \x03(\x0b\x32/.oi.papi.SubscriptionCreateRequest.Subscription\x1a^\n\x0cSubscription\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12(\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t2q\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponseP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBSCRIPTIONCREATEREQUEST._serialized_start=83
  _SUBSCRIPTIONCREATEREQUEST._serialized_end=278
  _SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION._serialized_start=184
  _SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION._serialized_end=278
  _SUBSCRIPTIONCREATERESPONSE._serialized_start=280
  _SUBSCRIPTIONCREATERESPONSE._serialized_end=355
  _NOTIFICATIONAPI._serialized_start=357
  _NOTIFICATIONAPI._serialized_end=470
# @@protoc_insertion_point(module_scope)
